# `relationalai.std`

The `relationalai.std` namespace contains the RelationalAI Query Builder Standard Library.

- [`alias()`](./alias.md)
- [`Vars`](./Vars.md)

## [`relationalai.std.aggregates`](./aggregates/README.md)

- [`aggregates.avg()`](./aggregates/avg.md)
- [`aggregates.count()`](./aggregates/count.md)
- [`aggregates.max()`](./aggregates/max.md)
- [`aggregates.min()`](./aggregates/min.md)
- [`aggregates.rank_asc()`](./aggregates/rank_asc.md)
- [`aggregates.rank_desc()`](./aggregates/rank_desc.md)
- [`aggregates.sum()`](./aggregates/sum.md)

## [`relationalai.std.graphs`](./graphs/README.md)

- [`graphs.Compute`](./graphs/Compute/README.md)
  - [`graphs.Compute.adamic_adar()`](./graphs/Compute/adamic_adar.md)
  - [`graphs.Compute.avg_clustering_coefficient()`](./graphs/Compute/avg_clustering_coefficient.md)
  - [`graphs.Compute.avg_degree()`](./graphs/Compute/avg_degree.md)
  - [`graphs.Compute.avg_indegree()`](./graphs/Compute/avg_indegree.md)
  - [`graphs.Compute.avg_outdegree()`](./graphs/Compute/avg_outdegree.md)
  - [`graphs.Compute.betweenness_centrality()`](./graphs/Compute/betweeness_centrality.md)
  - [`graphs.Compute.common_neighbor()`](./graphs/Compute/common_neighbor.md)
  - [`graphs.Compute.cosine_similarity()`](./graphs/Compute/cosine_similarity.md)
  - [`graphs.Compute.common_neighbor()`](./graphs/Compute/common_neighbor.md)
  - [`graphs.Compute.degree_centrality()`](./graphs/Compute/degree_centrality.md)
  - [`graphs.Compute.degree()`](./graphs/Compute/degree.md)
  - [`graphs.Compute.diameter_range()`](./graphs/Compute/diameter_range.md)
  - [`graphs.Compute.distance()`](./graphs/Compute/distance.md)
  - [`graphs.Compute.eigenvector_centrality()`](./graphs/Compute/eigenvector_centrality.md)
  - [`graphs.Compute.is_connected()`](./graphs/Compute/is_connected.md)
  - [`graphs.Compute.is_reachable()`](./graphs/Compute/is_reachable.md)
  - [`graphs.Compute.is_triangle()`](./graphs/Compute/is_triangle.md)
  - [`graphs.Compute.indegree()`](./graphs/Compute/indegree.md)
  - [`graphs.Compute.label_propagation()`](./graphs/Compute/label_propagation.md)
  - [`graphs.Compute.local_clustering_coefficient()`](./graphs/Compute/local_clustering_coefficient.md)
  - [`graphs.Compute.louvain()`](./graphs/Compute/louvain.md)
  - [`graphs.Compute.max_degree()`](./graphs/Compute/max_degree.md)
  - [`graphs.Compute.max_indegree()`](./graphs/Compute/max_indegree.md)
  - [`graphs.Compute.max_outdegree()`](./graphs/Compute/max_outdegree.md)
  - [`graphs.Compute.min_degree()`](./graphs/Compute/min_degree.md)
  - [`graphs.Compute.min_indegree()`](./graphs/Compute/min_indegree.md)
  - [`graphs.Compute.min_outdegree()`](./graphs/Compute/min_outdegree.md)
  - [`graphs.Compute.num_edges()`](./graphs/Compute/num_edges.md)
  - [`graphs.Compute.num_nodes()`](./graphs/Compute/num_nodes.md)
  - [`graphs.Compute.num_triangles()`](./graphs/Compute/num_triangles.md)
  - [`graphs.Compute.outdegree()`](./graphs/Compute/outdegree.md)
  - [`graphs.Compute.pagerank()`](./graphs/Compute/pagerank.md)
  - [`graphs.Compute.preferential_attachment()`](./graphs/Compute/preferential_attachment.md)
  - [`graphs.Compute.reachable_from()`](./graphs/Compute/reachable_from.md)
  - [`graphs.Compute.triangles()`](./graphs/Compute/triangles.md)
  - [`graphs.Compute.weakly_connected_component()`](./graphs/Compute/weakly_connected_component.md)
  - [`graphs.Compute.weighted_distance()`](./graphs/Compute/weighted_distance.md)
  - [`graphs.Compute.weighted_cosine_similarity()`](./graphs/Compute/weighted_cosine_similarity.md)
  - [`graphs.Compute.weighted_degree_centrality()`](./graphs/Compute/weighted_degree_centrality.md)
  - [`graphs.Compute.weighted_jaccard_similarity()`](./graphs/Compute/weighted_jaccard_similarity.md)
- [`graphs.Edge`](./graphs/Edge/README.md)
  - [`graphs.Edge.__call__()`](./graphs/Edge/call__.md)
  - [`graphs.Edge.add()`](./graphs/Edge/add.md)
  - [`graphs.Edge.extend()`](./graphs/Edge/extend.md)
- [`graphs.EdgeInstance`](./graphs/EdgeInstance/README.md)
  - [`graphs.EdgeInstance.from_`](./graphs/EdgeInstance/from_.md)
  - [`graphs.EdgeInstance.to`](./graphs/EdgeInstance/to.md)
  - [`graphs.EdgeInstance.set()`](./graphs/EdgeInstance/set.md)
- [`graphs.Graph`](./graphs/Graph/README.md)
  - [`graphs.Graph.compute`](./graphs/Graph/compute.md)
  - [`graphs.Graph.Edge`](./graphs/Graph/Edge.md)
  - [`graphs.Graph.fetch()`](./graphs/Graph/fetch.md)
  - [`graphs.Graph.id`](./graphs/Graph/id.md)
  - [`graphs.Graph.model`](./graphs/Graph/model.md)
  - [`graphs.Graph.Node`](./graphs/Graph/Node.md)
  - [`graphs.Graph.undirected`](./graphs/Graph/undirected.md)
  - [`graphs.Graph.visualize()`](./graphs/Graph/visualize.md)
  
## [`relationalai.std.math`](./math/README.md)

- [`math.abs()`](./math/abs.md)
- [`math.acos()`](./math/acos.md)
- [`math.asin()`](./math/asin.md)
- [`math.atan()`](./math/atan.md)
- [`math.isclose()`](./math/isclose.md)
- [`math.ceil()`](./math/ceil.md)
- [`math.cbrt()`](./math/cbrt.md)
- [`math.cos()`](./math/cos.md)
- [`math.degrees()`](./math/degrees.md)
- [`math.floor()`](./math/floor.md)
- [`math.log()`](./math/log.md)
- [`math.radians()`](./math/radians.md)
- [`math.sign()`](./math/sign.md)
- [`math.sin()`](./math/sin.md)
- [`math.sqrt()`](./math/sqrt.md)
- [`math.tan()`](./math/tan.md)
- [`math.trunc_divide()`](./math/trunc_divide.md)

## [`relationalai.std.strings`](./strings/README.md)

- [`strings.concat()`](./strings/concat.md)
- [`strings.contains()`](./strings/contains.md)
- [`strings.ends_with()`](./strings/ends_with.md)
- [`strings.join()`](./strings/join.md)
- [`strings.length()`](./strings/length.md)
- [`strings.like()`](./strings/like.md)
- [`strings.lowercase()`](./strings/lowercase.md)
- [`strings.regex_compile()`](./strings/regex_compile.md)
- [`strings.regex_match()`](./strings/regex_match.md)
- [`strings.replace()`](./strings/replace.md)
- [`strings.split()`](./strings/split.md)
- [`strings.split_part()`](./strings/split_part.md)
- [`strings.uppercase()`](./strings/uppercase.md)
